// $Id: EmuDuration.cc 6786 2007-08-04 10:29:59Z m9710797 $

#include "EmuDuration.hh"
#include <limits>

namespace openmsx {

const EmuDuration EmuDuration::zero(uint64(0));
const EmuDuration EmuDuration::infinity(std::numeric_limits<uint64>::max());

} // namespace openmsx
